@@ -1,6 +1,6 @@
 from pkgutil import extend_path
-
 __path__ = extend_path(__path__, __name__)
 
-from .email import EmailService
-from .email_config import EmailConfig
\ No newline at end of file
+from .email_service import EmailService
+from .email_config import EmailConfig
+
